@@ -1,17 +1,17 @@
-from .autodraw import AutoDraw
 from .canvas import Canvas
+from .source import Source
 from .client import Client
 from .color import Color
 from .exceptions import *  # NOQA
 from .ratelimits import RateLimitedEndpoint, Ratelimits
 
-__version__ = "0.0.6"
+__version__ = "0.1.0"
 
 __all__ = [
     "Canvas",
+    "Source",
     "Client",
     "Color",
     "Ratelimits",
     "RateLimitedEndpoint",
-    "AutoDraw",
 ]
